#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

import sys

from cloudonecli.clidriver import main


if __name__ == "__main__":
    sys.exit(main())
